@@ -98,55 +98,55 @@ KDatMainWindow::KDatMainWindow()
 
     // Create object popup menus.
     _tapeDriveMenu = new TQPopupMenu();
-    _tapeDriveMenu->insertItem( i18n( "Mount Tape" )         , this, TQT_SLOT( fileMountTape() ) );
-    _tapeDriveMenu->insertItem( i18n( "Recreate Tape Index" ), this, TQT_SLOT( fileIndexTape() ) );
+    _tapeDriveMenu->insertItem( i18n( "Mount Tape" )         , this, TQ_SLOT( fileMountTape() ) );
+    _tapeDriveMenu->insertItem( i18n( "Recreate Tape Index" ), this, TQ_SLOT( fileIndexTape() ) );
     _tapeDriveMenu->insertSeparator();
-    _tapeDriveMenu->insertItem( i18n( "Format Tape..." ), this, TQT_SLOT( fileFormatTape() ) );
+    _tapeDriveMenu->insertItem( i18n( "Format Tape..." ), this, TQ_SLOT( fileFormatTape() ) );
 
     _archiveMenu = new TQPopupMenu();
-    _archiveMenu->insertItem( i18n( "Delete Archive" ), this, TQT_SLOT( fileDeleteArchive() ) );
+    _archiveMenu->insertItem( i18n( "Delete Archive" ), this, TQ_SLOT( fileDeleteArchive() ) );
 
     _mountedArchiveMenu = new TQPopupMenu();
-    _mountedArchiveMenu->insertItem( i18n( "Verify..." )     , this, TQT_SLOT( fileVerify() ) );
-    _mountedArchiveMenu->insertItem( i18n( "Restore..." )    , this, TQT_SLOT( fileRestore() ) );
+    _mountedArchiveMenu->insertItem( i18n( "Verify..." )     , this, TQ_SLOT( fileVerify() ) );
+    _mountedArchiveMenu->insertItem( i18n( "Restore..." )    , this, TQ_SLOT( fileRestore() ) );
     _mountedArchiveMenu->insertSeparator();
-    _mountedArchiveMenu->insertItem( i18n( "Delete Archive" ), this, TQT_SLOT( fileDeleteArchive() ) );
+    _mountedArchiveMenu->insertItem( i18n( "Delete Archive" ), this, TQ_SLOT( fileDeleteArchive() ) );
 
     _mountedTapeFileMenu = new TQPopupMenu();
-    _mountedTapeFileMenu->insertItem( i18n( "Verify..." ) , this, TQT_SLOT( fileVerify() ) );
-    _mountedTapeFileMenu->insertItem( i18n( "Restore..." ), this, TQT_SLOT( fileRestore() ) );
+    _mountedTapeFileMenu->insertItem( i18n( "Verify..." ) , this, TQ_SLOT( fileVerify() ) );
+    _mountedTapeFileMenu->insertItem( i18n( "Restore..." ), this, TQ_SLOT( fileRestore() ) );
 
     _localFileMenu = new TQPopupMenu();
-    _localFileMenu->insertItem( i18n( "Backup..." ), this, TQT_SLOT( fileBackup() ) );
+    _localFileMenu->insertItem( i18n( "Backup..." ), this, TQ_SLOT( fileBackup() ) );
 
     _tapeMenu = new TQPopupMenu();
-    _tapeMenu->insertItem( i18n( "Delete Tape Index" ), this, TQT_SLOT( fileDeleteIndex() ) );
+    _tapeMenu->insertItem( i18n( "Delete Tape Index" ), this, TQ_SLOT( fileDeleteIndex() ) );
 
     _backupProfileRootMenu = new TQPopupMenu();
-    _backupProfileRootMenu->insertItem( i18n( "Create Backup Profile" ), this, TQT_SLOT( fileNewBackupProfile() ) );
+    _backupProfileRootMenu->insertItem( i18n( "Create Backup Profile" ), this, TQ_SLOT( fileNewBackupProfile() ) );
 
     _backupProfileMenu = new TQPopupMenu();
-    _backupProfileMenu->insertItem( i18n( "Backup..." ), this, TQT_SLOT( fileBackup() ) );
+    _backupProfileMenu->insertItem( i18n( "Backup..." ), this, TQ_SLOT( fileBackup() ) );
     _backupProfileMenu->insertSeparator();
-    _backupProfileMenu->insertItem( i18n( "Delete Backup Profile" ), this, TQT_SLOT( fileDeleteBackupProfile() ) );
+    _backupProfileMenu->insertItem( i18n( "Delete Backup Profile" ), this, TQ_SLOT( fileDeleteBackupProfile() ) );
 
     _fileMenu = new TQPopupMenu;
-    _fileMenu->insertItem( i18n( "Backup..." )            , this, TQT_SLOT( fileBackup() ) );
-    _fileMenu->insertItem( i18n( "Restore..." )           , this, TQT_SLOT( fileRestore() ) );
-    _fileMenu->insertItem( i18n( "Verify..." )            , this, TQT_SLOT( fileVerify() ) );
-    _fileMenu->insertItem( i18n( "Mount Tape" )           , this, TQT_SLOT( fileMountTape() ) );
-    _fileMenu->insertItem( i18n( "Recreate Tape Index" )  , this, TQT_SLOT( fileIndexTape() ) );
-    _fileMenu->insertItem( i18n( "Create Backup Profile" ), this, TQT_SLOT( fileNewBackupProfile() ) );
+    _fileMenu->insertItem( i18n( "Backup..." )            , this, TQ_SLOT( fileBackup() ) );
+    _fileMenu->insertItem( i18n( "Restore..." )           , this, TQ_SLOT( fileRestore() ) );
+    _fileMenu->insertItem( i18n( "Verify..." )            , this, TQ_SLOT( fileVerify() ) );
+    _fileMenu->insertItem( i18n( "Mount Tape" )           , this, TQ_SLOT( fileMountTape() ) );
+    _fileMenu->insertItem( i18n( "Recreate Tape Index" )  , this, TQ_SLOT( fileIndexTape() ) );
+    _fileMenu->insertItem( i18n( "Create Backup Profile" ), this, TQ_SLOT( fileNewBackupProfile() ) );
     _fileMenu->insertSeparator();
-    _fileMenu->insertItem( i18n( "Delete Archive" )       , this, TQT_SLOT( fileDeleteArchive() ) );
-    _fileMenu->insertItem( i18n( "Delete Index" )         , this, TQT_SLOT( fileDeleteIndex() ) );
-    _fileMenu->insertItem( i18n( "Delete Backup Profile" ), this, TQT_SLOT( fileDeleteBackupProfile() ) );
-    _fileMenu->insertItem( i18n( "Format Tape..." )       , this, TQT_SLOT( fileFormatTape() ) );
+    _fileMenu->insertItem( i18n( "Delete Archive" )       , this, TQ_SLOT( fileDeleteArchive() ) );
+    _fileMenu->insertItem( i18n( "Delete Index" )         , this, TQ_SLOT( fileDeleteIndex() ) );
+    _fileMenu->insertItem( i18n( "Delete Backup Profile" ), this, TQ_SLOT( fileDeleteBackupProfile() ) );
+    _fileMenu->insertItem( i18n( "Format Tape..." )       , this, TQ_SLOT( fileFormatTape() ) );
     _fileMenu->insertSeparator();
-    _fileMenu->insertItem( SmallIcon("system-log-out"), i18n( "&Quit" )                , this, TQT_SLOT( fileQuit() ), CTRL + Key_Q );
+    _fileMenu->insertItem( SmallIcon("system-log-out"), i18n( "&Quit" )                , this, TQ_SLOT( fileQuit() ), CTRL + Key_Q );
 
     _editMenu = new TQPopupMenu;
-    _editMenu->insertItem( SmallIcon("configure"), i18n( "Configure KDat..." )       , this, TQT_SLOT( editPreferences() ) );
+    _editMenu->insertItem( SmallIcon("configure"), i18n( "Configure KDat..." )       , this, TQ_SLOT( editPreferences() ) );
 
     _menu = new KMenuBar( this );
     _menu->insertItem( i18n( "&File" ), _fileMenu );
@@ -157,15 +157,15 @@ KDatMainWindow::KDatMainWindow()
 
     _toolbar = new TDEToolBar( this );
 
-    _toolbar->insertButton( *ImageCache::instance()->getTapeUnmounted(), 0, TQT_SIGNAL( clicked( int ) ), TQT_TQOBJECT(this), TQT_SLOT( fileMountTape() ), TRUE, i18n( "Mount/unmount tape" ) );
+    _toolbar->insertButton( *ImageCache::instance()->getTapeUnmounted(), 0, TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( fileMountTape() ), TRUE, i18n( "Mount/unmount tape" ) );
 
     _toolbar->insertSeparator();
 
-    _toolbar->insertButton( *ImageCache::instance()->getBackup() , 1, TQT_SIGNAL( clicked( int ) ), TQT_TQOBJECT(this), TQT_SLOT( fileBackup() ) , TRUE, i18n( "Backup" ) );
+    _toolbar->insertButton( *ImageCache::instance()->getBackup() , 1, TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( fileBackup() ) , TRUE, i18n( "Backup" ) );
     _toolbar->setButtonIconSet( 1, BarIconSet("kdat_backup"));
-    _toolbar->insertButton( *ImageCache::instance()->getRestore(), 2, TQT_SIGNAL( clicked( int ) ), TQT_TQOBJECT(this), TQT_SLOT( fileRestore() ), TRUE, i18n( "Restore" ) );
+    _toolbar->insertButton( *ImageCache::instance()->getRestore(), 2, TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( fileRestore() ), TRUE, i18n( "Restore" ) );
     _toolbar->setButtonIconSet( 2, BarIconSet("kdat_restore"));
-    _toolbar->insertButton( *ImageCache::instance()->getVerify() , 3, TQT_SIGNAL( clicked( int ) ), TQT_TQOBJECT(this), TQT_SLOT( fileVerify() ) , TRUE, i18n( "Verify" ) );
+    _toolbar->insertButton( *ImageCache::instance()->getVerify() , 3, TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( fileVerify() ) , TRUE, i18n( "Verify" ) );
     _toolbar->setButtonIconSet( 3, BarIconSet("kdat_verify"));
     addToolBar( _toolbar );
 
@@ -173,9 +173,9 @@ KDatMainWindow::KDatMainWindow()
     _statusBar->insertItem( i18n( "Ready." ), 0 );
 
 #ifdef KDAT_HORIZONTAL_LAYOUT      /* 2002-01-20 LEW */
-    _panner = new TQSplitter( Qt::Horizontal, this, "panner");
+    _panner = new TQSplitter( TQt::Horizontal, this, "panner");
 #else
-    _panner = new TQSplitter( Qt::Vertical, this, "panner");
+    _panner = new TQSplitter( TQt::Vertical, this, "panner");
 #endif /* KDAT_HORIZONTAL_LAYOUT */
 
     // Create info viewers.
@@ -197,12 +197,12 @@ KDatMainWindow::KDatMainWindow()
     _tree->setMinimumHeight( 300 );
 #endif /* KDAT_HORIZONTAL_LAYOUT */
 
-    connect( _tree, TQT_SIGNAL( expanding( KTreeViewItem*, bool& ) ), this, TQT_SLOT( localExpanding( KTreeViewItem*, bool& ) ) );
-    connect( _tree, TQT_SIGNAL( expanded( int ) ), this, TQT_SLOT( localExpanded( int ) ) );
-    connect( _tree, TQT_SIGNAL( collapsed( int ) ), this, TQT_SLOT( localCollapsed( int ) ) );
-    connect( _tree, TQT_SIGNAL( selected( int ) ), this, TQT_SLOT( localSelected( int ) ) );
-    connect( _tree, TQT_SIGNAL( highlighted( int ) ), this, TQT_SLOT( localHighlighted( int ) ) );
-    connect( _tree, TQT_SIGNAL( popupMenu( int, const TQPoint& ) ), this, TQT_SLOT( localPopupMenu( int, const TQPoint& ) ) );
+    connect( _tree, TQ_SIGNAL( expanding( KTreeViewItem*, bool& ) ), this, TQ_SLOT( localExpanding( KTreeViewItem*, bool& ) ) );
+    connect( _tree, TQ_SIGNAL( expanded( int ) ), this, TQ_SLOT( localExpanded( int ) ) );
+    connect( _tree, TQ_SIGNAL( collapsed( int ) ), this, TQ_SLOT( localCollapsed( int ) ) );
+    connect( _tree, TQ_SIGNAL( selected( int ) ), this, TQ_SLOT( localSelected( int ) ) );
+    connect( _tree, TQ_SIGNAL( highlighted( int ) ), this, TQ_SLOT( localHighlighted( int ) ) );
+    connect( _tree, TQ_SIGNAL( popupMenu( int, const TQPoint& ) ), this, TQ_SLOT( localPopupMenu( int, const TQPoint& ) ) );
 
     setCentralWidget( _panner );
 
@@ -211,14 +211,14 @@ KDatMainWindow::KDatMainWindow()
     _tree->insertItem( _backupProfileRootNode = new BackupProfileRootNode() );
     _tree->insertItem( new TapeIndexRootNode() );
 
-    connect( TapeDrive::instance(), TQT_SIGNAL( sigStatus( const TQString & ) ), this, TQT_SLOT( status( const TQString & ) ) );
+    connect( TapeDrive::instance(), TQ_SIGNAL( sigStatus( const TQString & ) ), this, TQ_SLOT( status( const TQString & ) ) );
 
     setTapePresent( FALSE );
 
-    connect( Options::instance(), TQT_SIGNAL( sigTapeDevice() ), this, TQT_SLOT( slotTapeDevice() ) );
+    connect( Options::instance(), TQ_SIGNAL( sigTapeDevice() ), this, TQ_SLOT( slotTapeDevice() ) );
 
-    connect( TapeManager::instance(), TQT_SIGNAL( sigTapeMounted() )  , this, TQT_SLOT( slotTapeMounted() ) );
-    connect( TapeManager::instance(), TQT_SIGNAL( sigTapeUnmounted() ), this, TQT_SLOT( slotTapeUnmounted() ) );
+    connect( TapeManager::instance(), TQ_SIGNAL( sigTapeMounted() )  , this, TQ_SLOT( slotTapeMounted() ) );
+    connect( TapeManager::instance(), TQ_SIGNAL( sigTapeUnmounted() ), this, TQ_SLOT( slotTapeUnmounted() ) );
 
     configureUI( 0 );
 }
@@ -1354,7 +1354,7 @@ void KDatMainWindow::create_backup_dialog()
      to accomodate a wider message :( */
   //  _cancel->setGeometry( TQRect( 50, 170, 0, 0 ) );   /* 2002-01-28 LEW */
   _cancel->setGeometry( TQRect( 50, 230, 0, 0 ) );
-  connect( _cancel, TQT_SIGNAL( clicked() ), this, TQT_SLOT( backupCancel() ) );
+  connect( _cancel, TQ_SIGNAL( clicked() ), this, TQ_SLOT( backupCancel() ) );
 
   _continue = new KPushButton( KStdGuiItem::cont(), _backupdialog );
   _continue->setFixedSize( 80, _continue->sizeHint().height() );
@@ -1362,7 +1362,7 @@ void KDatMainWindow::create_backup_dialog()
   _continue->setDefault( TRUE );
   //  _continue->setGeometry( TQRect( 200, 170, 0, 0 ) );   /* 2002-01-28 LEW */
   _continue->setGeometry( TQRect( 200, 230, 0, 0 ) );
-  connect( _continue, TQT_SIGNAL( clicked() ), this, TQT_SLOT( backupContinue() ) );
+  connect( _continue, TQ_SIGNAL( clicked() ), this, TQ_SLOT( backupContinue() ) );
 
   _backupdialog->show();
 }
