@@ -23,7 +23,6 @@
 KNetworkConf::KNetworkConf(TQWidget *parent, const char *name) : DCOPObject("KNetworkConfIface"), KNetworkConfDlg(parent, name)
 {
   netInfo = 0L;
-  makeButtonsResizeable();
   config = new KNetworkConfigParser();
   klvCardList->setAllColumnsShowFocus(true);
   klvKnownHosts->setAllColumnsShowFocus(true);
@@ -34,14 +33,14 @@ KNetworkConf::KNetworkConf(TQWidget *parent, const char *name) : DCOPObject("KNe
   tooltip = new KProfilesListViewToolTip(klvProfilesList);
     
   //Connect signals emmitted by the backend to know when data is ready to be painted.
-  connect(config,TQT_SIGNAL(readyLoadingNetworkInfo()),this,TQT_SLOT(getNetworkInfoSlot()));
-  connect(config,TQT_SIGNAL(readyLoadingNetworkInfo()),this,TQT_SLOT(showMainWindow()));
-  connect(config,TQT_SIGNAL(readyLoadingNetworkInfo()),this,TQT_SLOT(enableSignals()));
-  connect(config, TQT_SIGNAL(setReadOnly(bool)),this,TQT_SLOT(setReadOnlySlot(bool)));
+  connect(config,TQ_SIGNAL(readyLoadingNetworkInfo()),this,TQ_SLOT(getNetworkInfoSlot()));
+  connect(config,TQ_SIGNAL(readyLoadingNetworkInfo()),this,TQ_SLOT(showMainWindow()));
+  connect(config,TQ_SIGNAL(readyLoadingNetworkInfo()),this,TQ_SLOT(enableSignals()));
+  connect(config, TQ_SIGNAL(setReadOnly(bool)),this,TQ_SLOT(setReadOnlySlot(bool)));
   connect(klvCardList,
-          TQT_SIGNAL(contextMenu(TDEListView*,TQListViewItem*,const TQPoint&)),
+          TQ_SIGNAL(contextMenu(TDEListView*,TQListViewItem*,const TQPoint&)),
           this,
-          TQT_SLOT(showInterfaceContextMenuSlot(TDEListView*,TQListViewItem*, const TQPoint&)));
+          TQ_SLOT(showInterfaceContextMenuSlot(TDEListView*,TQListViewItem*, const TQPoint&)));
 
   // Register with DCOP - No longer needed as now we are a kcontrol module?
   if ( !kapp->dcopClient()->isRegistered() ) {
@@ -152,7 +151,7 @@ void KNetworkConf::loadNetworkDevicesInfo()
  */
 void KNetworkConf::quitSlot(){
   int code = 0;
-  connect( config, TQT_SIGNAL(readyLoadingNetworkInfo()), this, TQT_SLOT(quitSlot()) );
+  connect( config, TQ_SIGNAL(readyLoadingNetworkInfo()), this, TQ_SLOT(quitSlot()) );
   if (modified)
   {
     code = KMessageBox::warningYesNoCancel(this,
@@ -571,7 +570,7 @@ void KNetworkConf::disableAll(){
   kleDomainName->setReadOnly(true);
   tlDomainName->setEnabled(false);
   tlHostName->setEnabled(false);
-  disconnect(klvCardList,TQT_SIGNAL(doubleClicked(TQListViewItem *)),this,TQT_SLOT(configureDeviceSlot()));
+  disconnect(klvCardList,TQ_SIGNAL(doubleClicked(TQListViewItem *)),this,TQ_SLOT(configureDeviceSlot()));
   klvCardList->setEnabled(false);
   kpbUpButton->setEnabled(false);
   kpbDownButton->setEnabled(false);
@@ -686,7 +685,7 @@ void KNetworkConf::changeDeviceState(const TQString &dev, int state){
   dialog->setModal(true);
   dialog->show();
 
-  procDeviceState = new TQProcess(TQT_TQOBJECT(this));
+  procDeviceState = new TQProcess(this);
   TQString cmd;
   procDeviceState->addArgument( locate("data",BACKEND_PATH) );
 
@@ -703,10 +702,10 @@ void KNetworkConf::changeDeviceState(const TQString &dev, int state){
   else if (state == DEVICE_DOWN)
     procDeviceState->addArgument("enable_iface::"+dev+"::0" );
 
-  connect( procDeviceState, TQT_SIGNAL(readyReadStdout()),this, TQT_SLOT(readFromStdoutUpDown()) );
-  connect( procDeviceState, TQT_SIGNAL(readyReadStderr()),this, TQT_SLOT(readFromStdErrUpDown()) );
-  connect( procDeviceState, TQT_SIGNAL(processExited()),this, TQT_SLOT(verifyDeviceStateChanged()) );
-  connect( procDeviceState, TQT_SIGNAL(processExited()), dialog, TQT_SLOT(close()) );
+  connect( procDeviceState, TQ_SIGNAL(readyReadStdout()),this, TQ_SLOT(readFromStdoutUpDown()) );
+  connect( procDeviceState, TQ_SIGNAL(readyReadStderr()),this, TQ_SLOT(readFromStdErrUpDown()) );
+  connect( procDeviceState, TQ_SIGNAL(processExited()),this, TQ_SLOT(verifyDeviceStateChanged()) );
+  connect( procDeviceState, TQ_SIGNAL(processExited()), dialog, TQ_SLOT(close()) );
 
   currentDevice = dev;
   commandOutput = "";
@@ -810,20 +809,6 @@ bool KNetworkConf::valuesChanged(KNetworkInterface *dev,
     return false;
 }
 
-/** Sets the TQPushButton::autoResize() in true for all buttons. */
-void KNetworkConf::makeButtonsResizeable(){
-  kpbConfigureNetworkInterface->setAutoResize(true);
-  kcbGwDevice->setAutoResize(true);
-  kpbAddDomainServer->setAutoResize(true);
-  kpbEditDomainServer->setAutoResize(true);
-  kpbRemoveDomainServer->setAutoResize(true);
-  kpbUpButton->setAutoResize(true);
-  kpbDownButton->setAutoResize(true);
-  kpbAddKnownHost->setAutoResize(true);
-  kpbEditKnownHost->setAutoResize(true);
-  kpbRemoveKnownHost->setAutoResize(true);
-}
-
 void KNetworkConf::enableInterfaceSlot()
 {
   if (modified) {
@@ -986,8 +971,8 @@ void KNetworkConf::showInterfaceContextMenuSlot(TDEListView* lv, TQListViewItem*
 
   TDEPopupMenu *context = new TDEPopupMenu( this );
   TQ_CHECK_PTR( context );
-  context->insertItem( "&Enable Interface", this, TQT_SLOT(enableInterfaceSlot()));
-  context->insertItem( "&Disable Interface", this, TQT_SLOT(disableInterfaceSlot()));
+  context->insertItem( "&Enable Interface", this, TQ_SLOT(enableInterfaceSlot()));
+  context->insertItem( "&Disable Interface", this, TQ_SLOT(disableInterfaceSlot()));
   TQListViewItem *item = klvCardList->currentItem();
   TQString currentDevice = item->text(0);
   KNetworkInterface *dev = getDeviceInfo(currentDevice);
@@ -1003,17 +988,17 @@ void KNetworkConf::showInterfaceContextMenuSlot(TDEListView* lv, TQListViewItem*
     context->setItemEnabled(1,false);
   }
   context->insertSeparator(2);
-  context->insertItem( "&Configure Interface...", this, TQT_SLOT(configureDeviceSlot()));
+  context->insertItem( "&Configure Interface...", this, TQ_SLOT(configureDeviceSlot()));
   context->popup(pt);
-  //context->insertItem( "About &TQt", this, TQT_SLOT(aboutTQt()) );
+  //context->insertItem( "About &TQt", this, TQ_SLOT(aboutTQt()) );
 }
 
 void KNetworkConf::enableSignals()
 {
   tooltip->setProfiles(netInfo->getProfilesList());
-  connect(kleDefaultRoute,TQT_SIGNAL(textChanged(const TQString&)),this,TQT_SLOT(enableApplyButtonSlot(const TQString&)));
-  connect(kleDomainName,TQT_SIGNAL(textChanged(const TQString&)),this,TQT_SLOT(enableApplyButtonSlot(const TQString&)));
-  connect(kleHostName,TQT_SIGNAL(textChanged(const TQString&)),this,TQT_SLOT(enableApplyButtonSlot(const TQString&)));
+  connect(kleDefaultRoute,TQ_SIGNAL(textChanged(const TQString&)),this,TQ_SLOT(enableApplyButtonSlot(const TQString&)));
+  connect(kleDomainName,TQ_SIGNAL(textChanged(const TQString&)),this,TQ_SLOT(enableApplyButtonSlot(const TQString&)));
+  connect(kleHostName,TQ_SIGNAL(textChanged(const TQString&)),this,TQ_SLOT(enableApplyButtonSlot(const TQString&)));
 }
 
 void KNetworkConf::enableProfileSlot()
@@ -1032,7 +1017,7 @@ void KNetworkConf::enableProfileSlot()
       profile->setProfilesList(netInfo->getProfilesList()); 
       config->saveNetworkInfo(profile);
       modified = false;
-      //connect( config, TQT_SIGNAL(readyLoadingNetworkInfo()), this, TQT_SLOT(showSelectedProfile(selectedProfile)) );
+      //connect( config, TQ_SIGNAL(readyLoadingNetworkInfo()), this, TQ_SLOT(showSelectedProfile(selectedProfile)) );
     }
     else
       KMessageBox::error(this,
